@@ -3,7 +3,7 @@ use warnings;
 
 package HTTP::Async;
 
-our $VERSION = '0.26';
+our $VERSION = '0.30';
 
 use Carp;
 use Data::Dumper;
@@ -84,7 +84,7 @@ However in some circumstances you might wish to change these.
             slots:  20
           timeout:  180 (seconds)
  max_request_time:  300 (seconds)
-    max_redirects:  7
+    max_redirect:   7
     poll_interval:  0.05 (seconds)
        proxy_host:  ''
        proxy_port:  ''
@@ -92,8 +92,12 @@ However in some circumstances you might wish to change these.
        local_port:  ''
        ssl_options: {}
        cookie_jar:  undef
+       peer_addr:   ''
 
 If defined, is expected to be similar to C<HTTP::Cookies>, with extract_cookies and add_cookie_header methods.
+
+The option max_redirects has been renamed to max_redirect to be consistent with LWP::UserAgent, although max_redirects still works.
+
        
 =head1 METHODS
 
@@ -112,7 +116,7 @@ sub new {
 
         opts => {
             slots            => 20,
-            max_redirects    => 7,
+            max_redirect     => 7,
             timeout          => 180,
             max_request_time => 300,
             poll_interval    => 0.05,
@@ -143,7 +147,7 @@ sub _init {
 
 sub _next_id { return ++$_[0]->{current_id} }
 
-=head2 slots, timeout, max_request_time, poll_interval, max_redirects, proxy_host, proxy_port, local_addr, local_port, ssl_options, cookie_jar
+=head2 slots, timeout, max_request_time, poll_interval, max_redirect, proxy_host, proxy_port, local_addr, local_port, ssl_options, cookie_jar, peer_addr
 
     $old_value = $async->slots;
     $new_value = $async->slots( $new_value );
@@ -156,8 +160,8 @@ Slots is the maximum number of parallel requests to make.
 =cut
 
 my %GET_SET_KEYS = map { $_ => 1 } qw( slots poll_interval
-  timeout max_request_time max_redirects
-  proxy_host proxy_port local_addr local_port ssl_options cookie_jar);
+  timeout max_request_time max_redirect
+  proxy_host proxy_port local_addr local_port ssl_options cookie_jar peer_addr);
 
 sub _add_get_set_key {
     my $class = shift;
@@ -165,10 +169,15 @@ sub _add_get_set_key {
     $GET_SET_KEYS{$key} = 1;
 }
 
+my %KEY_ALIASES = ( max_redirects => 'max_redirect' );
+
 sub _get_opt {
     my $self = shift;
     my $key  = shift;
     my $id   = shift;
+
+    $key = $KEY_ALIASES{$key} if exists $KEY_ALIASES{$key};
+
     die "$key not valid for _get_opt" unless $GET_SET_KEYS{$key};
 
     # If there is an option set for this id then use that, otherwise fall back
@@ -183,6 +192,9 @@ sub _get_opt {
 sub _set_opt {
     my $self = shift;
     my $key  = shift;
+
+    $key = $KEY_ALIASES{$key} if exists $KEY_ALIASES{$key};
+
     die "$key not valid for _set_opt" unless $GET_SET_KEYS{$key};
     $self->{opts}{$key} = shift if @_;
     return $self->{opts}{$key};
@@ -230,13 +242,20 @@ This method lets you add a single request to the queue with options that
 differ from the defaults. For example you might wish to set a longer timeout
 or to use a specific proxy. Returns the id of the request.
 
+The method croaks when passed an invalid option.
+
 =cut
 
 sub add_with_opts {
     my $self = shift;
     my $req  = shift;
     my $opts = shift;
-    my $id   = $self->_next_id;
+
+    for my $key (keys %{$opts}) {
+        croak "$key not valid for add_with_opts" unless $GET_SET_KEYS{$key};
+    }
+
+    my $id = $self->_next_id;
 
     push @{ $$self{to_send} }, [ $req, $id ];
     $self->{id_opts}{$id} = $opts;
@@ -782,13 +801,25 @@ sub _send_request {
     $args{LocalAddr} = $self->_get_opt('local_addr', $id );
     $args{LocalPort} = $self->_get_opt('local_port', $id );
 
+    # https://rt.cpan.org/Public/Bug/Display.html?id=33071
+    $args{Timeout} = $self->_get_opt( 'timeout', $id);
+
+    # ACF - Pass ssl_options through
+    $args{ssl_opts} = $self->_get_opt( 'ssl_options', $id);
+
     my $request_is_to_proxy =
       ( $args{PeerAddr} || $args{PeerPort} )    # if either are set...
       ? 1                                       # ...then we are a proxy request
       : 0;                                      # ...otherwise not
 
     # If we did not get a setting from the proxy then use the uri values.
+
     $args{PeerAddr} ||= $uri->host;
+    my $peer_address = $self->_get_opt('peer_addr', $id );
+    if($peer_address) {
+        $args{PeerAddr} = $peer_address;
+    }
+
     $args{PeerPort} ||= $uri->port;
 
     my $net_http_class = 'Net::HTTP::NB';
@@ -861,7 +892,7 @@ sub _send_request {
     $entry->{finish_by}  = $time + $self->_get_opt( 'max_request_time', $id );
     $entry->{handle}     = $s;
 
-    $entry->{redirects_left} = $self->_get_opt( 'max_redirects', $id )
+    $entry->{redirects_left} = $self->_get_opt( 'max_redirect', $id )
       unless exists $entry->{redirects_left};
 
     return 1;
